==> igniteui-angular-charts-14.1.1.tgz: package/esm2015/lib/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let PercentageVolumeOscillatorIndicator = /*@__PURE__*/ (() => {
    class PercentageVolumeOscillatorIndicator extends StrategyBasedIndicator {
        get_uh() {
            return new PercentageVolumeOscillatorIndicatorStrategy();
        }
        get uh() {
            return this.get_uh();
        }
        get_uu() {
            return PercentageVolumeOscillatorIndicator.$;
        }
        get uu() {
            return this.get_uu();
        }
        get shortPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.u3));
        }
        set shortPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.u3, a);
        }
        up() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.u2));
        }
        set longPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.u2, a);
        }
        um() {
            return this.longPeriod;
        }
    }
    PercentageVolumeOscillatorIndicator.$t = markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentageVolumeOscillatorIndicator.u3 = StrategyBasedIndicator.u1(10, PercentageVolumeOscillatorIndicator.$);
    PercentageVolumeOscillatorIndicator.u2 = StrategyBasedIndicator.ux(30, PercentageVolumeOscillatorIndicator.$);
    return PercentageVolumeOscillatorIndicator;
})();

==> igniteui-angular-charts-16.0.0.tgz: package/esm2015/lib/PercentageVolumeOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentageVolumeOscillatorIndicatorStrategy } from "./PercentageVolumeOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let PercentageVolumeOscillatorIndicator = /*@__PURE__*/ (() => {
    class PercentageVolumeOscillatorIndicator extends StrategyBasedIndicator {
        get_ul() {
            return new PercentageVolumeOscillatorIndicatorStrategy();
        }
        get ul() {
            return this.get_ul();
        }
        get_uy() {
            return PercentageVolumeOscillatorIndicator.$;
        }
        get uy() {
            return this.get_uy();
        }
        get shortPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.u7));
        }
        set shortPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.u7, a);
        }
        ut() {
            return this.shortPeriod;
        }
        get longPeriod() {
            return typeGetValue(this.c(PercentageVolumeOscillatorIndicator.u6));
        }
        set longPeriod(a) {
            this.h(PercentageVolumeOscillatorIndicator.u6, a);
        }
        uq() {
            return this.longPeriod;
        }
    }
    PercentageVolumeOscillatorIndicator.$t = markType(PercentageVolumeOscillatorIndicator, 'PercentageVolumeOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentageVolumeOscillatorIndicator.u7 = StrategyBasedIndicator.u5(10, PercentageVolumeOscillatorIndicator.$);
    PercentageVolumeOscillatorIndicator.u6 = StrategyBasedIndicator.u1(30, PercentageVolumeOscillatorIndicator.$);
    return PercentageVolumeOscillatorIndicator;
})();
